<?php
/**
 * callback for block configure form
 */
function _qr_codes_block_configure_form($delta = 0, $edit = array()) {
  $form = array();
  $form['qr_codes'] = array(
    '#type' => 'fieldset',
    '#title' => t('QR Codes Node Block'),
    '#collapsible' => FALSE,
  );
  
  $form['qr_codes']['qr_codes_block_data'] = array(
    '#type' => 'textarea',
    '#title' => t('Enter the text to embed in your barcode'),
    '#description' => t('Available token replacement patterns are listed below and will be applied on node or user pages.'),
    '#default_value' => variable_get('qr_codes_block_data', '')
  );
  
  if (module_exists('token')) {
    $form['qr_codes']['tokens'] = array(
      '#type' => 'fieldset',
      '#title' => t('Available Tokens'),
      '#collapsible' => TRUE,
      '#collapsed' => TRUE,
    );
    
    $form['qr_codes']['tokens']['help'] = array(
      '#value' => theme('token_help', 'node'),
    );
  }
  
  if(function_exists('imagecache_presets')){
    $options = array('');
    foreach((array)imagecache_presets() as $preset){
      $options[$preset['presetname']] = $preset['presetname'];
    }
    
    $form['qr_codes']['qr_codes_block_imagecache_preset'] = array(
      '#type' => 'select',
      '#title' => t('Select an Imagecache preset'),
      '#multiple' => FALSE,
      '#description' => t('If selected, this imagecache preset will be applied to the barcode image.'),
      '#options' => $options,
      '#default_value' => variable_get('qr_codes_block_imagecache_preset', -1),
    );
  }
  return $form;
}

/**
 * callback to handle save of block configure options
 */
function _qr_codes_block_configure_save($delta, $edit) {
  variable_set('qr_codes_block_data', $edit['qr_codes_block_data']);
  if (!empty($edit['qr_codes_block_imagecache_preset'])) {
    variable_set('qr_codes_block_imagecache_preset', $edit['qr_codes_block_imagecache_preset']);
  }
}

/**
 * callback to handle view of qr_codes block
 */
function _qr_codes_block_view($delta, $edit) {
  $block['subject'] = t('QR Codes');

  $data = variable_get('qr_codes_block_data', '');
  
  // use token replacement if available for nodes and users
  $tokens = module_exists('token');
  global $user;
  if (arg(0) == 'node' && is_numeric(arg(1)) && $tokens) {
    $data = token_replace($data, 'node', node_load(arg(1)));
  }
  if ($tokens && $user->uid) {
    $data = token_replace($data, 'user', $user);
  }
  
  $block['content'] = theme('qr_codes', $data, 150, 150, 0, variable_get('qr_codes_block_imagecache_preset', ''));
  return $block;
}